abacusai.address — AbacusAI documentation

# abacusai.address

## Classes

`Address` | Address object

## Module Contents

class abacusai.address.Address(client, addressLine1=None, addressLine2=None, city=None, stateOrProvince=None, postalCode=None, country=None, additionalInfo=None, includeReverseCharge=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Address object

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - addressLine1 (str) – The first line of the address

    - addressLine2 (str) – The second line of the address

    - city (str) – The city

    - stateOrProvince (str) – The state or province

    - postalCode (str) – The postal code

    - country (str) – The country

    - additionalInfo (str) – Additional information for invoice

    - includeReverseCharge (bool) – Whether the organization needs the reverse charge mechanism applied to invoices.

  address_line_1 = None
  address_line_2 = None
  city = None
  state_or_province = None
  postal_code = None
  country = None
  additional_info = None
  include_reverse_charge = None
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict